url = "https://test.annahub.dev/"
sequence = (
	"send_keys",
	"submit",
	"click",
	"hover",
	"wait",
	"select",
	"switch_to",
	"iframe.send_keys",
	"iframe.submit",
	"iframe.click",
	"iframe.hover",
	"iframe.wait"
)
